@@ -1,18 +1,24 @@
 """Runway module module."""
-# (couldn't resist ^)
 
 import logging
 import os
+import platform
 import subprocess
 import sys
 
 from ..util import which
 
 LOGGER = logging.getLogger('runway')
+NPM_BIN = 'npm.cmd' if platform.system().lower() == 'windows' else 'npm'
+NPX_BIN = 'npx.cmd' if platform.system().lower() == 'windows' else 'npx'
 
 
 def format_npm_command_for_logging(command):
     """Convert npm command list to string for display to user."""
+    if platform.system().lower() == 'windows':
+        if command[0] == 'npx.cmd' and command[1] == '-c':
+            return "npx.cmd -c \"%s\"" % " ".join(command[2:])
+        return " ".join(command)
     # Strip out redundant npx quotes not needed when executing the command
     # directly
     return " ".join(command).replace('\'\'', '\'')
@@ -20,14 +26,19 @@ def format_npm_command_for_logging(command):
 
 def generate_node_command(command, command_opts, path):
     """Return node bin command list for subprocess execution."""
-    if which('npx'):
+    if which(NPX_BIN):
         # Use npx if available (npm v5.2+)
         LOGGER.debug("Using npx to invoke %s.", command)
-        # The nested cdk-through-npx-via-subprocess command invocation
-        # requires this redundant quoting
-        cmd_list = ['npx',
-                    '-c',
-                    "''%s %s''" % (command, ' '.join(command_opts))]
+        if platform.system().lower() == 'windows':
+            cmd_list = [NPX_BIN,
+                        '-c',
+                        "%s %s" % (command, ' '.join(command_opts))]
+        else:
+            # The nested app-through-npx-via-subprocess command invocation
+            # requires this redundant quoting
+            cmd_list = [NPX_BIN,
+                        '-c',
+                        "''%s %s''" % (command, ' '.join(command_opts))]
     else:
         LOGGER.debug('npx not found; falling back invoking %s shell script '
                      'directly.', command)
@@ -40,34 +51,15 @@ def generate_node_command(command, command_opts, path):
     return cmd_list
 
 
-def warn_on_skipped_configs(result, env_name, env_vars):
-    """Print a helper note about how the environment was determined."""
-    env_override_name = 'DEPLOY_ENVIRONMENT'
-    if ('skipped_configs' in result and
-            result['skipped_configs']):
-        if env_override_name in env_vars:
-            LOGGER.info("Environment \"%s\" was determined from the %s "
-                        "environment variable. If this is not correct, update "
-                        "the value (or unset it to fall back to the name of "
-                        "the current git branch or parent directory).",
-                        env_name,
-                        env_override_name)
-        else:
-            LOGGER.info("Environment \"%s\" was determined from the current "
-                        "git branch or parent directory. If this is not the "
-                        "environment name, update the branch/folder name or "
-                        "set an override value via the %s environment "
-                        "variable",
-                        env_name,
-                        env_override_name)
-
-
-def run_module_command(cmd_list, env_vars):
+def run_module_command(cmd_list, env_vars, exit_on_error=True):
     """Shell out to provisioner command."""
-    try:
+    if exit_on_error:
+        try:
+            subprocess.check_call(cmd_list, env=env_vars)
+        except subprocess.CalledProcessError as shelloutexc:
+            sys.exit(shelloutexc.returncode)
+    else:
         subprocess.check_call(cmd_list, env=env_vars)
-    except subprocess.CalledProcessError as shelloutexc:
-        sys.exit(shelloutexc.returncode)
 
 
 def use_npm_ci(path):
@@ -79,10 +71,9 @@ def use_npm_ci(path):
              os.path.isfile(os.path.join(path,
                                          'npm-shrinkwrap.json'))) and
                 subprocess.call(
-                    ['npm', 'ci', '-h'],
+                    [NPM_BIN, 'ci', '-h'],
                     stdout=fnull,
-                    stderr=subprocess.STDOUT
-                ) == 0):
+                    stderr=subprocess.STDOUT) == 0):
             return True
     return False
 
@@ -90,17 +81,27 @@ def use_npm_ci(path):
 def run_npm_install(path, options, context):
     """Run npm install/ci."""
     # Use npm ci if available (npm v5.7+)
-    if options.get('skip_npm_ci'):
+    if options.get('options', {}).get('skip_npm_ci'):
         LOGGER.info("Skipping npm ci or npm install on %s...",
                     os.path.basename(path))
-    elif context.env_vars.get('CI') and use_npm_ci(path):  # noqa
+    elif context.env_vars.get('CI') and use_npm_ci(path):
         LOGGER.info("Running npm ci on %s...",
                     os.path.basename(path))
-        subprocess.check_call(['npm', 'ci'])
+        subprocess.check_call([NPM_BIN, 'ci'])
     else:
         LOGGER.info("Running npm install on %s...",
                     os.path.basename(path))
-        subprocess.check_call(['npm', 'install'])
+        subprocess.check_call([NPM_BIN, 'install'])
+
+
+def warn_on_boto_env_vars(env_vars):
+    """Inform user if boto-specific environment variables are in use."""
+    # https://github.com/serverless/serverless/issues/2151#issuecomment-255646512
+    if env_vars.get('AWS_DEFAULT_PROFILE') and not (
+            env_vars.get('AWS_PROFILE')):
+        LOGGER.warning('AWS_DEFAULT_PROFILE environment variable is set '
+                       'during use of nodejs-based module and AWS_PROFILE is '
+                       'not set -- you likely want to set AWS_PROFILE instead')
 
 
 class RunwayModule(object):
@@ -117,6 +118,9 @@ class RunwayModule(object):
         else:
             self.options = options
 
+    # the rest of these 'abstract' methods must have names which match
+    #  the commands defined in `cli.py`
+
     def plan(self):
         """Implement dummy method (set in consuming classes)."""
         raise NotImplementedError('You must implement the plan() method '
